<p align="center">
  <a href="https://v2.nonebot.dev/"><img src="https://v2.nonebot.dev/logo.png" width="200" height="200" alt="nonebot"></a>
</p>


<div align="center">
  
**你的star是我的动力**  
**↓**  
<img src="https://img.shields.io/github/stars/yzyyz1387/nonebot_plugin_workscore.svg?style=social">  

# 工作性价比计算器📱 (alpha only)

_✨ NoneBot2 工作性价比计算插件 ✨_

</div>
算法来自知乎，可自行百度
计算结果仅供参考

## 安装💿
`pip install nonebot-plugin-workscore`


## 导入📲
在**bot.py** 导入，语句：
`nonebot.load_plugin("nonebot_plugin_workscore")`



## 目录结构📂

```
├─imgs
├   └─shuang.png.
├   └─shaungboom.png
├   └─yiban.png
├   └─cjrh.jpg
├   └─1.jpg
├   └─2.jpg
├─__init__.py

```


## 指令💻
`ces = on_command("workscore",aliases={"算性价比","性价比计算器","工作性价比"},rule=to_me())`
即常见形式为私聊，@或者叫机器人的昵称并说 “算性价比”
**示例**
`@Eternity. 算性价比`
`bot 算性价比`
`@机器人 算性价比`

**给个star吧~**

## 其他插件  
[简易群管](https://github.com/yzyyz1387/nonebot_plugin_admin)  
[在线运行代码](https://github.com/yzyyz1387/nonebot_plugin_code)  
[it咨讯（垃圾插件）](https://github.com/yzyyz1387/nonebot_plugin_itnews "it资讯")  
[工作性价比（还没更新beta不能用）](https://github.com/yzyyz1387/nonebot_plugin_workscore)  
[黑丝插件（jsdelivr问题国内服务器不能用）](https://github.com/yzyyz1387/nonebot_plugin_heisi)

## 截图🖼

![](https://cdn.jsdelivr.net/gh/yzyyz1387/blogimages/nonebot_plugin_workscore.jpg)



